ahbicht.content\_evaluation.rc\_evaluators module
=================================================

.. automodule:: ahbicht.content_evaluation.rc_evaluators
   :members:
   :undoc-members:
   :show-inheritance:
